@@ -291,6 +291,9 @@ nact_match_list_init_view( BaseWindow *window, const gchar *tab_name )
 	gtk_tree_sortable_set_sort_column_id( GTK_TREE_SORTABLE( model ), ITEM_COLUMN, GTK_SORT_ASCENDING );
 	data->sort_column = ITEM_COLUMN;
 	data->sort_order = GTK_SORT_ASCENDING;
+
+	column = gtk_tree_view_get_column( data->listview, ITEM_COLUMN );
+	sort_on_column( column, data, ITEM_COLUMN );
 }
 
 /**
@@ -542,13 +545,17 @@ on_key_pressed_event( GtkWidget *widget, GdkEventKey *event, MatchListStr *data
 	}
 
 	if( event->keyval == GDK_Insert || event->keyval == GDK_KP_Insert ){
-		insert_new_row( data );
-		stop = TRUE;
+		if( data->editable_item ){
+			insert_new_row( data );
+			stop = TRUE;
+		}
 	}
 
 	if( event->keyval == GDK_Delete || event->keyval == GDK_KP_Delete ){
-		delete_current_row( data );
-		stop = TRUE;
+		if( data->editable_item ){
+			delete_current_row( data );
+			stop = TRUE;
+		}
 	}
 
 	return( stop );
@@ -576,39 +583,48 @@ on_must_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str, Ma
 	NAIContext *context;
 	GSList *filters;
 	gchar *to_remove;
+	gboolean active;
 
 	/*gboolean is_active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 	g_debug( "%s: is_active=%s", thisfn, is_active ? "True":"False" );*/
 
-	if( !gtk_cell_renderer_toggle_get_active( cell_renderer )){
-		context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
-		g_return_if_fail( NA_IS_ICONTEXT( context ));
+	active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 
-		set_match_status( path_str, TRUE, FALSE, data );
+	if( data->editable_item ){
+		if( !active ){
+			context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
+			g_return_if_fail( NA_IS_ICONTEXT( context ));
 
-		filter = get_filter_from_path( path_str, data );
-		filters = ( *data->pget )( context );
+			set_match_status( path_str, TRUE, FALSE, data );
 
-		if( filters ){
-			to_remove = g_strdup_printf( "!%s", filter );
-			filters = na_core_utils_slist_remove_ascii( filters, to_remove );
-			g_free( to_remove );
+			filter = get_filter_from_path( path_str, data );
+			filters = ( *data->pget )( context );
+
+			if( filters ){
+				to_remove = g_strdup_printf( "!%s", filter );
+				filters = na_core_utils_slist_remove_ascii( filters, to_remove );
+				g_free( to_remove );
+			}
+
+			filters = g_slist_prepend( filters, g_strdup( filter ));
+			( *data->pset )( context, filters );
+
+			na_core_utils_slist_free( filters );
+			g_free( filter );
+
+			g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
 		}
-
-		filters = g_slist_prepend( filters, filter );
-		( *data->pset )( context, filters );
-
-		na_core_utils_slist_free( filters );
-		g_free( filter );
-
-		g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
+	} else {
+		g_signal_handlers_block_by_func(( gpointer ) cell_renderer, on_must_match_toggled, data );
+		gtk_cell_renderer_toggle_set_active( cell_renderer, !active );
+		g_signal_handlers_unblock_by_func(( gpointer ) cell_renderer, on_must_match_toggled, data );
 	}
 }
 
 static void
 on_must_not_match_clicked( GtkTreeViewColumn *treeviewcolumn, MatchListStr *data )
 {
-	sort_on_column( treeviewcolumn, data, MUST_MATCH_COLUMN );
+	sort_on_column( treeviewcolumn, data, MUST_NOT_MATCH_COLUMN );
 }
 
 static void
@@ -619,31 +635,40 @@ on_must_not_match_toggled( GtkCellRendererToggle *cell_renderer, gchar *path_str
 	NAIContext *context;
 	GSList *filters;
 	gchar *to_add;
+	gboolean active;
 
 	/*gboolean is_active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 	g_debug( "%s: is_active=%s", thisfn, is_active ? "True":"False" );*/
 
-	if( !gtk_cell_renderer_toggle_get_active( cell_renderer )){
-		context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
-		g_return_if_fail( NA_IS_ICONTEXT( context ));
+	active = gtk_cell_renderer_toggle_get_active( cell_renderer );
 
-		set_match_status( path_str, FALSE, TRUE, data );
+	if( data->editable_item ){
+		if( !active ){
+			context = nact_main_tab_get_context( NACT_MAIN_WINDOW( data->window ), NULL );
+			g_return_if_fail( NA_IS_ICONTEXT( context ));
 
-		filter = get_filter_from_path( path_str, data );
-		filters = ( *data->pget )( context );
+			set_match_status( path_str, FALSE, TRUE, data );
 
-		if( filters ){
-			filters = na_core_utils_slist_remove_ascii( filters, filter );
+			filter = get_filter_from_path( path_str, data );
+			filters = ( *data->pget )( context );
+
+			if( filters ){
+				filters = na_core_utils_slist_remove_ascii( filters, filter );
+			}
+
+			to_add = g_strdup_printf( "!%s", filter );
+			filters = g_slist_prepend( filters, to_add );
+			( *data->pset )( context, filters );
+
+			na_core_utils_slist_free( filters );
+			g_free( filter );
+
+			g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
 		}
-
-		to_add = g_strdup_printf( "!%s", filter );
-		filters = g_slist_prepend( filters, to_add );
-		( *data->pset )( context, filters );
-
-		na_core_utils_slist_free( filters );
-		g_free( filter );
-
-		g_signal_emit_by_name( G_OBJECT( data->window ), TAB_UPDATABLE_SIGNAL_ITEM_UPDATED, context, FALSE );
+	} else {
+		g_signal_handlers_block_by_func(( gpointer ) cell_renderer, on_must_not_match_toggled, data );
+		gtk_cell_renderer_toggle_set_active( cell_renderer, !active );
+		g_signal_handlers_unblock_by_func(( gpointer ) cell_renderer, on_must_not_match_toggled, data );
 	}
 }
 
@@ -958,10 +983,14 @@ sort_on_column( GtkTreeViewColumn *treeviewcolumn, MatchListStr *data, guint new
 	guint prev_col_id;
 	guint prev_order, new_order;
 	GtkTreeModel *model;
+	GtkTreeViewColumn *column;
 
 	prev_col_id = data->sort_column;
 	prev_order = data->sort_order;
 
+	column = gtk_tree_view_get_column( data->listview, prev_col_id );
+	gtk_tree_view_column_set_sort_indicator( column, FALSE );
+
 	if( new_col_id == prev_col_id ){
 		new_order = ( prev_order == GTK_SORT_ASCENDING ? GTK_SORT_DESCENDING : GTK_SORT_ASCENDING );
 	} else {
@@ -971,6 +1000,9 @@ sort_on_column( GtkTreeViewColumn *treeviewcolumn, MatchListStr *data, guint new
 	data->sort_column = new_col_id;
 	data->sort_order = new_order;
 
+	gtk_tree_view_column_set_sort_indicator( treeviewcolumn, TRUE );
+	gtk_tree_view_column_set_sort_order( treeviewcolumn, new_order );
+
 	model = gtk_tree_view_get_model( data->listview );
 	gtk_tree_sortable_set_sort_column_id( GTK_TREE_SORTABLE( model ), new_col_id, new_order );
 }
